ZCoerceImpl class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bool(
) → ZCoerceBoolean -
inherited
-
date(
) → ZCoerceDate -
inherited
-
double(
) → ZCoerceDouble -
inherited
-
int(
) → ZCoerceInt -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
num(
) → ZCoerceNum -
inherited
-
string(
) → ZCoerceString -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited